@@ -1,12 +1,11 @@
 import unittest
 from unittest import TestCase
-import numpy as np
 from clouddrift import timeseries
 
 if __name__ == "__main__":
     unittest.main()
 
 
-class spectrum_tests(TestCase):
-    def example(self):
+class timeseries_tests(TestCase):
+    def test_example(self):
         pass
